@@ -1,3 +1,5 @@
+import re
+
 import requests
 import time
 import logging
@@ -19,7 +21,7 @@ class WeakNetworkConfig(object):
     ATC_SHAPE_URI = "/api/v1/shape/{}/"
 
     def __init__(self, atc_host="http://172.29.182.152:8000", stf_url=None, sft_token=None, wifi_name="yy_net",
-                 wifi_password="", weak_network_ip="192.168.1"):
+                 wifi_password="", weak_network_ip=["192.168.1", "192.168.0"]):
         """
             :param atc_host: atc服务地址
             :param stf_url: sft服务器地址
@@ -83,7 +85,7 @@ class WeakNetworkConfig(object):
             return self._disconnect_android(serial)
 
     def _connect_android(self, serial):
-        timeout = 5 * 60
+        timeout = 60
         t1 = time.time()
         while True:
             if time.time() - t1 > timeout:
@@ -91,7 +93,7 @@ class WeakNetworkConfig(object):
             self._stf.toggleAndroidWifi(serial, "1", wifiname=self._wifi_name, wifipass=self._wifi_password)
             ip = self._stf.get_android_device_ip(serial)
             logger.info("get_android_device_ip :{} return ip :{}".format(serial, ip))
-            if str(ip).startswith(self.weak_network_ip):
+            if self.get_pre_ip(str(ip)) in self.weak_network_ip:
                 self.set_auth(ip)
                 return ip
             else:
@@ -117,7 +119,7 @@ class WeakNetworkConfig(object):
             logger.info("get device_ip {}".format(device_ip))
             if device_ip:
                 # 弱网断网现在是192.168.0 如果网段变化则需要修改下面的逻辑
-                if device_ip.startswith(self.weak_network_ip):
+                if self.get_pre_ip(str(device_ip)) in self.weak_network_ip:
                     self.set_auth(device_ip)
                     return device_ip
                 else:
@@ -129,7 +131,7 @@ class WeakNetworkConfig(object):
         ret = self._stf.toggleAndroidWifi(serial, "3", self._wifi_name, self._wifi_password)
         logger.info("_disconnect_android response".format(ret))
         ip = ret.get("ip", None)
-        if not str(ip).startswith(self.weak_network_ip):
+        if not self.get_pre_ip(str(ip)) in self.weak_network_ip:
             return True
         else:
             return False
@@ -151,7 +153,7 @@ class WeakNetworkConfig(object):
             logger.info("get device_ip {}".format(device_ip))
             if device_ip:
                 # 弱网断网现在是192.168.0 如果网段变化则需要修改下面的逻辑
-                if not device_ip.startswith(self.weak_network_ip):
+                if not self.get_pre_ip(str(device_ip)) in self.weak_network_ip:
                     logger.info("device:{} 断开弱网连接".format(serial))
                     break
                 else:
@@ -189,3 +191,10 @@ class WeakNetworkConfig(object):
                 return False
         except Exception as e:
             return False
+
+    def get_pre_ip(self, ip):
+        if ip:
+            search_re = f"(\d+.\d+.\d+).\d+"
+            return re.search(search_re, ip).group(1) if re.search(search_re, ip) is not None else ""
+        else:
+            return ""
\ No newline at end of file
